
"""

Kibrit
======

The module for watching SCM (git, hg, svn).
Use it for control a static's versions.

"""

__version__ = '0.3'
__project__ = __name__
__author__ = "Sinan Midillili <sinanm89@gmail.com>"
__license__ = "MIT"